@@ -135,6 +135,8 @@ mappingObjMarray <- function(obj,
     if(length(grep(newchr, pattern="y")>0)){
       newchr[grep(newchr, pattern="y")]= (max(suppressWarnings(as.numeric(newchr)), na.rm=TRUE)+1)
     }
+  }else{
+    newchr = chr
   }
 
   #
@@ -164,7 +166,7 @@ mappingObjMarray <- function(obj,
 
     # convert location if needed
     mapping.info$loc.center= as.numeric(locdata)
-    if(locBy == "within") mapping.info$g.loc.center = convertCloc(as.numeric(locdata), as.numeric(newchr))
+    if(locBy == "within") mapping.info$g.loc.center = convertCloc(as.numeric(locdata), newchr)
     if(locBy == "across") mapping.info$g.loc.center = as.numeric(locdata)
     
     mapping.info$g.loc.stop= mapping.info$g.loc.center
@@ -211,9 +213,9 @@ mappingObjMarray <- function(obj,
 
     # convert location if needed 
     if(locBy == "across"){
-      mapping.info$g.loc.start = convertGloc(startData, as.numeric(newchr))
-      mapping.info$g.loc.stop = convertGloc(endData, as.numeric(newchr))
-      mapping.info$g.loc.center = (as.numeric(convertGloc(startData, as.numeric(newchr)))+as.numeric(convertGloc(endData, as.numeric(newchr))))/2
+      mapping.info$g.loc.start = convertGloc(startData, newchr)
+      mapping.info$g.loc.stop = convertGloc(endData, newchr)
+      mapping.info$g.loc.center = (as.numeric(convertGloc(startData, newchr))+as.numeric(convertGloc(endData, newchr)))/2
     }
     if(locBy == "within"){
       mapping.info$g.loc.start = startData
